# CFLAGS and library paths for libparted
# written by Damien Genet <damien.genet@free.fr>

dnl Usage:
dnl AM_PATH_PARTED([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl
dnl Example:
dnl AM_PATH_PARTED(1.2.6, , AC_MSG_ERROR([*** libparted >= 1.2.6 not installed - please install first ***]))
dnl
dnl Add -lparted to LIBS 
dnl


AC_DEFUN(AM_PATH_PARTED,
[

dnl Check for headers and library
AC_CHECK_HEADER(parted/parted.h,,
            AC_MSG_ERROR([*** libparted headers not found - please install libparted ***])
            $3)
AC_CHECK_LIB(parted,ped_init,,
            AC_MSG_ERROR([*** libparted not found - please install libparted ***])
            $3)

dnl Add -lparted to library flags
LIBS="$LIBS -lparted"


AC_MSG_CHECKING(for libparted - version >= $1)

dnl Get major, minor, and micro version from arg MINIMUM-VERSION
parted_config_major_version=`echo $1 | \
    sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
parted_config_minor_version=`echo $1 | \
    sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
parted_config_micro_version=`echo $1 | \
    sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

dnl Compare MINIMUM-VERSION with libparted version
AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <parted/parted.h>

int main ()
{
	int	major, minor, micro;
	char	*version;    
	
	version = ped_get_version ();
	if (sscanf(version, "%d.%d.%d", &major, &minor, &micro) != 3) {
		printf("%s, bad version string\n", version);
		exit(1);
	}
	
	if ((major > $parted_config_major_version) ||
	   ((major == $parted_config_major_version) && (minor > $parted_config_minor_version)) ||
	   ((major == $parted_config_major_version) && (minor == $parted_config_minor_version) && (micro > $parted_config_micro_version))) {
		return 0;
	} else {
		printf("\n*** An old version of libparted (%s) was found.\n",
		       version);
		printf("*** You need a version of libparted newer than %d.%d.%d.\n",
			$parted_config_major_version, 
			$parted_config_minor_version,
			$parted_config_micro_version);
		printf("*** You can get it at - ftp://ftp.gnu.org/gnu/parted/\n");
		return 1;
	}
}
], 
    AC_MSG_RESULT(yes),
    $3, [echo $ac_n "cross compiling; assumed OK... $ac_c"])

dnl Execute ACTION-IF-FOUND
$2

])
